/* Sistemas Integrados TEKNISA

Nome: 0001_LSGSTPO_LSG_GERA_NOTAFISCAL.SQL

@C:\web_542\sql\end_conv\oracle\clientes\lsg\0007_LSGSTPO_LSG_GERA_NOTAFISCAL.SQL

Descrio:
Rotina para gerao de notas fiscais (entrada e sada) e
movimentao de estoque (integrao BONDED).

Criao:
30/12/2009 - Cleison Rafael da Silva Ferreira
*/

CREATE OR REPLACE PROCEDURE LSG_GERA_NOTAFISCAL
(
   P_CDFILIAL   IN   NOTAFISCAL.CDFILIAL%TYPE,
   P_CDTIPOPERE IN   NOTAFISCAL.CDTIPOOPER%TYPE,
   P_CDTIPOPERS IN   NOTAFISCAL.CDTIPOOPER%TYPE,
   P_CDSERIE    IN   NOTAFISCAL.CDSERIE%TYPE
)
AS
   V_CDEMPRESA     VARCHAR2(02);
   V_INSCESTA      VARCHAR2(16);
   V_NRINSJURNF    VARCHAR2(20);
   V_NMPRODUTO     VARCHAR2(50);
   V_NRLOTEESTQ    VARCHAR2(20);
   V_INSCMUNI      VARCHAR2(16);
   V_IDTPIJURNF    VARCHAR2(01);
   V_NRLANCTONF    VARCHAR2(10);
   V_CDCLIENTE     VARCHAR2(21);
   V_NFINSJURCLIE  VARCHAR2(20);
   V_NVCIAPROD     VARCHAR2(02);
   V_CDPRODUTO     VARCHAR2(20);
   V_SGUNIDADE     VARCHAR2(10);
   V_CDARVPROD     VARCHAR2(20);
   V_SEQ           VARCHAR2(04);
   V_NRLANCTOE     VARCHAR2(20);
   V_NRLANCTOS     VARCHAR2(20);
   V_NRLANCESTE    VARCHAR2(20);
   V_NRLANCESTS    VARCHAR2(20);
   V_CHAVEUNICA    VARCHAR2(22);
   V_SEQITEM       VARCHAR2(04);
   V_ERRO          VARCHAR2(01);
   V_SEQDADOS      VARCHAR2(10);
   V_TOTPROD       FLOAT;
   V_VRNOTAFISC    FLOAT;
   V_VRFATOCONV    FLOAT;
BEGIN
   V_CHAVEUNICA := 'A';
   FOR C_NF IN (SELECT LSG_CHAVEUNICA, LSG_CDCOMPANHIA, LSG_CODDI
                  FROM LSG_NFBONDEDTMP
                 ORDER BY LSG_CHAVEUNICA) LOOP
/* Verifica se a nota fiscal j foi importada*/
      BEGIN
         SELECT MAX(NRLANCTONF)
           INTO V_NRLANCTONF
           FROM NOTAFISCAL
          WHERE LSG_IDBONDED = C_NF.LSG_CHAVEUNICA;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_NRLANCTONF := NULL;
      END;
/*Importa as notas que ainda no foram importadas*/
      IF V_NRLANCTONF IS NULL THEN
         IF (V_CHAVEUNICA <> C_NF.LSG_CHAVEUNICA) THEN
/*Grava Chave nica para evitar importao da mesma vrias vezes*/
            V_CHAVEUNICA := C_NF.LSG_CHAVEUNICA;
/*Verifica se a Companhia informada existe no sistema*/
            BEGIN
               SELECT L.NRINSJURCLIE, B.LSG_NVCIAPROD
                 INTO V_NRINSJURNF, V_NVCIAPROD
                 FROM LSG_COAEREABOND B, COMPANHIA C, CLIENTE L
                WHERE B.LSG_CDCIA     = C.CDCIA
                  AND C.CDCLIENTE     = L.CDCLIENTE
                  AND UPPER(B.LSG_CDCIABOND) = UPPER(C_NF.LSG_CDCOMPANHIA);
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NRINSJURNF  := NULL;
                  V_NVCIAPROD   := NULL;
            END;
/*Se a companhia no existe, grava mensagem de erro*/
            IF V_NRINSJURNF IS NULL THEN
               INSERT INTO LSG_ERRBONDEDTMP
                  (LSG_DSERROSBOND)
               VALUES
                  ('Cdigo da Companhia '||C_NF.LSG_CDCOMPANHIA||' no relacionada nos sistemas Teknisa.');
            ELSE
/*Rotina de gerao das notas*/
               SELECT CDEMPRESA
                 INTO V_CDEMPRESA
                 FROM FILIAL
                WHERE CDFILIAL = P_CDFILIAL;

               BEGIN
                  SELECT MAX(CDINSCESTA), MAX(CDINSCMUNI)
                    INTO V_INSCESTA, V_INSCMUNI
                    FROM EMPRCNTRFIL
                   WHERE (CDFILIAL  = P_CDFILIAL) AND
                         (CDEMPRESA = V_CDEMPRESA);
               EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                     V_INSCESTA := NULL;
                     V_INSCMUNI := NULL;
               END;
               IF (V_INSCESTA IS NULL) OR (V_INSCMUNI IS NULL) THEN
                  SELECT MAX(CDINSCESTA), MAX(CDINSCMUNI)
                    INTO V_INSCESTA, V_INSCMUNI
                    FROM FILIAL
                   WHERE (CDFILIAL  = P_CDFILIAL) AND
                         (CDEMPRESA = V_CDEMPRESA);
               END IF;

               BEGIN
                  SELECT CDFORNECED, IDTPIJURFORN
                    INTO V_CDCLIENTE, V_IDTPIJURNF
                    FROM FORNECEDOR
                   WHERE NRINSJURFORN = V_NRINSJURNF;
               EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                     V_CDCLIENTE := NULL;
               END;

/*Se no houver fornecedor cadastrado, grava na tabela de erro*/
               IF V_CDCLIENTE IS NULL THEN
                  INSERT INTO LSG_ERRBONDEDTMP
                     (LSG_DSERROSBOND)
                  VALUES
                     ('No h fornecedor cadastrado para a companhia '||C_NF.LSG_CDCOMPANHIA||'.');
               ELSE
/*Gera Nota Fiscal de Entrada*/
                  NOVO_CODIGO('LANCNF/FILIAL' || P_CDFILIAL, V_NRLANCTOE);
                  V_NRLANCTOE := SUBSTR(V_NRLANCTOE, 11, 10);
                  INSERT INTO NOTAFISCAL
                     (CDFILIAL,     NRLANCTONF,        CDEMPRESA,     CDINSCESTA,
                      CDINSCMUNI,   CDFILIEMIT,        CDFILIRECE,    NRINSJURNF,
                      IDBLOQUEADO,  IDDOCFISCAL,       IDDOCFINANC,   DTENTRSAID,
                      VRPRODUTOS,   VRNOTAFISC,        IDENTRSAIDOP,  CDTIPOOPER,
                      CDSERIE,      IDDOCCONTAB,       DTEXPORTACAO,  IDDOCFISCENT,
                      CDMODDOCFISC, CDALMOXARIFE,      CDLOCALESTOQ,  DTEMISSAO,
                      CDFORNECED,   CDCLIENTE,         IDTPIJURNF,    NRNOTAFISC,
                      CDSERIEENTR,  IDSISTEMA,         IDORIGDESTNF,  LSG_IDBONDED)
                  VALUES
                     (P_CDFILIAL, V_NRLANCTOE, V_CDEMPRESA, V_INSCESTA,
                      V_INSCMUNI, P_CDFILIAL, P_CDFILIAL, V_NRINSJURNF,
                      'S', 'S', 'S', TO_DATE(SYSDATE),
                      0, 0, 'E', P_CDTIPOPERE,
                      P_CDSERIE, 'S', TO_DATE(SYSDATE), 'N',
                      '99', ' ', ' ',    TO_DATE(SYSDATE),
                      V_CDCLIENTE, '', V_IDTPIJURNF, '',
                      P_CDSERIE, 'DFE', 'F', C_NF.LSG_CHAVEUNICA);
/*Gera os dados adicionais da nota de entrada*/
                  V_SEQDADOS := '001';
                  FOR C_DI IN (SELECT DISTINCT LSG_CODDI
                                 FROM LSG_NFBONDEDTMP
                                WHERE LSG_CHAVEUNICA = C_NF.LSG_CHAVEUNICA) LOOP
                     INSERT INTO DADOSADIC
                        (CDFILIAL, NRLANCTONF,
                         NRDADOADIC, DSDADOADIC)
                     VALUES
                        (P_CDFILIAL, V_NRLANCTOE,
                         V_SEQDADOS, C_DI.LSG_CODDI);
                     V_SEQDADOS := LPAD(TO_CHAR(TO_NUMBER(V_SEQDADOS)+1),3,'000');
                  END LOOP;
/*Gera entrada no estoque para lanamento de entrada*/
                  NOVO_CODIGO('LANCTOEST' || P_CDFILIAL, V_NRLANCESTE);
                  V_NRLANCESTE := SUBSTR(V_NRLANCESTE, 11, 10);
                  INSERT INTO LANCTOESTOQ
                     (CDFILIAL, NRLANCESTQ, DSLANCESTQ,
                      IDTPLANCTO, CDTIPOOPER, DTLANCESTQ,
                      IDENTRSAIDOP, CDFILIMOVI, NRLANCTONF)
                  VALUES
                     (P_CDFILIAL, V_NRLANCESTE, 'Importao Bonded',
                      'E', P_CDTIPOPERE, TO_DATE(SYSDATE),
                      'E', P_CDFILIAL, V_NRLANCTOE);

/*Rotina de Gerao da Nota Fiscal de Sada*/
                  SELECT CDCLIENTE, IDTPIJURCLIE
                    INTO V_CDCLIENTE, V_IDTPIJURNF
                    FROM CLIENTE
                   WHERE NRINSJURCLIE = V_NRINSJURNF;
/*Gera Nota Fiscal*/
                  NOVO_CODIGO('LANCNF/FILIAL' || P_CDFILIAL, V_NRLANCTOS);
                  V_NRLANCTOS := SUBSTR(V_NRLANCTOS, 11, 10);
                  INSERT INTO NOTAFISCAL
                     (CDFILIAL,     NRLANCTONF,        CDEMPRESA,     CDINSCESTA,
                      CDINSCMUNI,   CDFILIEMIT,        CDFILIRECE,    NRINSJURNF,
                      IDBLOQUEADO,  IDDOCFISCAL,       IDDOCFINANC,   DTENTRSAID,
                      VRPRODUTOS,   VRNOTAFISC,        IDENTRSAIDOP,  CDTIPOOPER,
                      CDSERIE,      IDDOCCONTAB,       DTEXPORTACAO,  IDDOCFISCENT,
                      CDMODDOCFISC, CDALMOXARIFE,      CDLOCALESTOQ,  DTEMISSAO,
                      CDFORNECED,   CDCLIENTE,         IDTPIJURNF,    NRNOTAFISC,
                      CDSERIEENTR,  IDSISTEMA,         IDORIGDESTNF,  LSG_IDBONDED)
                  VALUES
                     (P_CDFILIAL, V_NRLANCTOS, V_CDEMPRESA, V_INSCESTA,
                      V_INSCMUNI, P_CDFILIAL, P_CDFILIAL, V_NRINSJURNF,
                      'S', 'S', 'S', TO_DATE(SYSDATE),
                      0, 0, 'S', P_CDTIPOPERS,
                      P_CDSERIE, 'S', TO_DATE(SYSDATE), 'N',
                      '99', ' ', ' ',    TO_DATE(SYSDATE),
                      '', V_CDCLIENTE, V_IDTPIJURNF, '',
                      P_CDSERIE, 'DFS', 'C', C_NF.LSG_CHAVEUNICA);
/*Gera os dados adicionais da nota de sada*/
                  V_SEQDADOS := '001';
                  FOR C_DI IN (SELECT DISTINCT LSG_CODDI
                                 FROM LSG_NFBONDEDTMP
                                WHERE LSG_CHAVEUNICA = C_NF.LSG_CHAVEUNICA) LOOP
                     INSERT INTO DADOSADIC
                        (CDFILIAL, NRLANCTONF,
                         NRDADOADIC, DSDADOADIC)
                     VALUES
                        (P_CDFILIAL, V_NRLANCTOS,
                         V_SEQDADOS, C_DI.LSG_CODDI);
                     V_SEQDADOS := LPAD(TO_CHAR(TO_NUMBER(V_SEQDADOS)+1),3,'000');
                  END LOOP;
/*Gera entrada no estoque para lanamento de sada*/
                  NOVO_CODIGO('LANCTOEST' || P_CDFILIAL, V_NRLANCESTS);
                  V_NRLANCESTS := SUBSTR(V_NRLANCESTS, 11, 10);
                  INSERT INTO LANCTOESTOQ
                     (CDFILIAL, NRLANCESTQ, DSLANCESTQ,
                      IDTPLANCTO, CDTIPOOPER, DTLANCESTQ,
                      IDENTRSAIDOP, CDFILIMOVI, NRLANCTONF)
                  VALUES
                     (P_CDFILIAL, V_NRLANCESTS, 'Importao Bonded',
                      'S', P_CDTIPOPERS, TO_DATE(SYSDATE),
                      'S', P_CDFILIAL, V_NRLANCTOS);

/*Rotina de Importao dos itens*/
                  V_SEQITEM := '0001';
                  V_ERRO := '0';
                  V_TOTPROD := 0;
                  FOR C_ITEM IN (SELECT LSG_CDPRODUTO, LSG_NMPRODUTO, LSG_UNMEDIDA,
                                        LSG_QTITEMPROD, LSG_VRUNITPROD, LSG_VRTOTAPROD
                                   FROM LSG_NFBONDEDTMP
                                  WHERE LSG_CHAVEUNICA = C_NF.LSG_CHAVEUNICA) LOOP
                     BEGIN
                        SELECT CDPRODUTO
                          INTO V_CDPRODUTO
                          FROM PRODUTO
                         WHERE CDPRODINTE = C_ITEM.LSG_CDPRODUTO
                           AND IDPRODCOMISS IS NULL
                           AND CDARVPROD LIKE 'B%';
                     EXCEPTION
                        WHEN NO_DATA_FOUND THEN
                           V_CDPRODUTO := NULL;
                     END;
/*Se o produto no existe, insere o mesmo no sistema*/
                     IF V_CDPRODUTO IS NULL THEN
/*Verifica se a unidade de medida est cadastrada no sistema*/
                        BEGIN
                           SELECT U.SGUNIDADE
                             INTO V_SGUNIDADE
                             FROM LSG_UNIDMEDBOND L, UNIDMEDIDA U
                            WHERE L.LSG_SGUNIDADE  = U.SGUNIDADE
                              AND UPPER(L.LSG_SGUNIDBOND) = UPPER(C_ITEM.LSG_UNMEDIDA);
                        EXCEPTION
                           WHEN NO_DATA_FOUND THEN
                              V_SGUNIDADE := NULL;
                        END;
/*Se no existe, grava mensagem de erro*/
                        IF V_SGUNIDADE IS NULL THEN
                           V_ERRO := '1';
                           INSERT INTO LSG_ERRBONDEDTMP
                              (LSG_DSERROSBOND)
                           VALUES
                              ('Unidade de medida '||C_ITEM.LSG_UNMEDIDA||' no relacionada nos sistemas Teknisa.');
                        ELSE
/*Verifica se existe os nveis anteriores do produto*/
                           BEGIN
                              SELECT CDARVPROD
                                INTO V_CDARVPROD
                                FROM PRODUTO
                               WHERE CDARVPROD = 'B'|| V_NVCIAPROD ||'01001'
                                 AND CDNVPRODUTO = '4';
                           EXCEPTION
                              WHEN NO_DATA_FOUND THEN
                                 V_CDARVPROD := NULL;
                           END;
/*Se no existir nvel anterior, grava mensagem de erro*/
                           IF V_CDARVPROD IS NULL THEN
                              V_ERRO := '1';
                              INSERT INTO LSG_ERRBONDEDTMP
                                 (LSG_DSERROSBOND)
                              VALUES
                                 ('Nvel de Produto no cadastrado para a companhia '||C_NF.LSG_CDCOMPANHIA||'.');
                           ELSE
/*Busca o sequencial do produto*/
                              BEGIN
                                 SELECT MAX(SUBSTR(CDARVPROD,9,4))
                                   INTO V_SEQ
                                   FROM PRODUTO
                                  WHERE CDARVPROD LIKE '%B'|| V_NVCIAPROD ||'01001%'
                                    AND CDNVPRODUTO = '5'
                                  ORDER BY CDARVPROD;
                              EXCEPTION
                                 WHEN NO_DATA_FOUND THEN
                                    V_SEQ := NULL;
                              END;
/*Gera o prximo sequencial*/
                              IF V_SEQ IS NULL THEN
                                 V_SEQ := '0000';
                              ELSE
                                 V_SEQ := LPAD(TO_CHAR(TO_NUMBER(V_SEQ)+1),4,'0000');
                              END IF;
/*Gera o cdigo do Produto e o cdigo de rvore*/
                              NOVO_CODIGO('PRODUTO', V_CDPRODUTO);
                              V_CDPRODUTO := SUBSTR(V_CDPRODUTO, 11, 10);
                              V_CDARVPROD := 'B'||V_NVCIAPROD||'01001'||V_SEQ; /*Cdigo de rvore do Produto*/
/*Grava o produto no sistema*/
                              INSERT INTO PRODUTO
                                 (CDPRODUTO, CDNVPRODUTO, SGUNIDADE, VRPEFATOCORR,
                                  NMPRODUTO, CDPRODINTE, CDARVPROD, CDPRODESTO)
                              VALUES
                                 (V_CDPRODUTO, '5', V_SGUNIDADE, 0,
                                  C_ITEM.LSG_NMPRODUTO, C_ITEM.LSG_CDPRODUTO, V_CDARVPROD, V_CDPRODUTO);

                              FOR C_PROD IN (SELECT F.CDFILIAL
                                               FROM FILIAL F, PARAMFILIAL P
                                              WHERE F.CDFILIAL = P.CDFILIAL AND
                                                    NVL(IDCTRLESTQ,'S') = 'S'
                                              MINUS
                                             SELECT CDFILIAL
                                               FROM PRODFILI
                                              WHERE CDPRODUTO = V_CDPRODUTO) LOOP

                                 INSERT INTO PRODFILI
                                    (CDFILIAL, CDPRODUTO)
                                 VALUES
                                    (C_PROD.CDFILIAL, V_CDPRODUTO);
                              END LOOP;
                           END IF;
                        END IF;
                     END IF;
                     IF V_CDPRODUTO IS NOT NULL THEN
/*Rotina de Gerao dos Itens da Nota de Sada*/
                        SELECT NMPRODUTO
                          INTO V_NMPRODUTO
                          FROM PRODUTO
                         WHERE CDPRODUTO = V_CDPRODUTO;
/*Verifica se h lote cadastrado para o produto*/
                        BEGIN
                           SELECT MAX(NRLOTEESTQ)
                             INTO V_NRLOTEESTQ
                             FROM LOTE
                            WHERE CDFILIAL   = P_CDFILIAL
                              AND CDPRODUTO  = V_CDPRODUTO
                              AND NRLOTEESTQ = ' '
                              AND NRSUBLOTE  = ' ';
                        EXCEPTION
                           WHEN NO_DATA_FOUND THEN
                              V_NRLOTEESTQ := NULL;
                        END;

                        IF V_NRLOTEESTQ IS NULL THEN
                           INSERT INTO LOTE
                              (CDFILIAL, NRLOTEESTQ, NRSUBLOTE,
                               CDPRODUTO, IDSTATLOTE, DTENTRLOTE)
                           VALUES
                              (P_CDFILIAL, ' ', ' ',
                               V_CDPRODUTO, 'L', TO_DATE(SYSDATE));
                        END IF;
/*Grava dados do item no estoque para lanamento de entrada*/
                        INSERT INTO ITLANCTOEST
                           (CDFILIAL, NRLANCESTQ, NRSEQUITEM, CDPRODUTO,
                            QTLANCTOEST, VRUNILANCTO, VRTOTLANCTO, QTTOTLANCTO,
                            CDPRODMOVI, CDFILIMOVI, CDALMOXARIFE, CDLOCALESTOQ,
                            NRLOTEESTQ, NRSUBLOTE, IDTIPOMOVI, DTLANCMOVI,
                            IDORDEMCLC, VRLANCTOEST, VRLANCTOBRUT)
                       VALUES
                          (P_CDFILIAL, V_NRLANCESTE, V_SEQITEM, V_CDPRODUTO,
                           ROUND(C_ITEM.LSG_QTITEMPROD,4), ROUND(C_ITEM.LSG_VRUNITPROD,4),
                           ROUND(C_ITEM.LSG_VRTOTAPROD,4), ROUND(C_ITEM.LSG_QTITEMPROD,4),
                           V_CDPRODUTO, P_CDFILIAL, ' ', ' ',
                           ' ', ' ', '2', TO_DATE(SYSDATE),
                           '2', ROUND(C_ITEM.LSG_VRUNITPROD,4), ROUND(C_ITEM.LSG_VRUNITPROD,4));

/*Grava dados do item na nota de entrada*/
                       INSERT INTO ITEMPRODUTO
                          (CDFILIAL,     NRLANCTONF,   NRSEQITPROD,  CDPRODUTO,
                           CDPRODEMIS,   DSPRODEMIS,   IDATUVRESTOQ, QTITEMPROD,
                           VRUNITITEM,   VRDESCITEM,   VRTOTAITEM,   VRCONTITEM,
                           IDCONFORITEM, VRBRUTITEM,   VRDESPERITEM, CDFILIMOVI,
                           CDALMOXARIFE, CDLOCALESTOQ, NRLOTEESTQ,   NRSUBLOTE)
                       VALUES
                          (P_CDFILIAL, V_NRLANCTOE, V_SEQITEM, V_CDPRODUTO,
                           V_CDPRODUTO, V_NMPRODUTO, 'S', ROUND(C_ITEM.LSG_QTITEMPROD,4),
                           ROUND(C_ITEM.LSG_VRUNITPROD,4), 0, ROUND(C_ITEM.LSG_VRTOTAPROD,4), ROUND(C_ITEM.LSG_VRTOTAPROD,4),
                          'S', ROUND(C_ITEM.LSG_VRTOTAPROD,4), 0, P_CDFILIAL,
                          ' ', ' ', ' ', ' ');

/*Grava dados do item no estoque para lanamento de sada*/
                       INSERT INTO ITLANCTOEST
                          (CDFILIAL, NRLANCESTQ, NRSEQUITEM, CDPRODUTO,
                           QTLANCTOEST, VRUNILANCTO,VRTOTLANCTO, QTTOTLANCTO,
                           CDPRODMOVI, CDFILIMOVI, CDALMOXARIFE, CDLOCALESTOQ,
                           NRLOTEESTQ, NRSUBLOTE, IDTIPOMOVI, DTLANCMOVI,
                           IDORDEMCLC, VRLANCTOEST, VRLANCTOBRUT)
                       VALUES
                          (P_CDFILIAL, V_NRLANCESTS, V_SEQITEM, V_CDPRODUTO,
                           ROUND(C_ITEM.LSG_QTITEMPROD,4), ROUND(C_ITEM.LSG_VRUNITPROD,4),
                           ROUND(C_ITEM.LSG_VRTOTAPROD,4), ROUND(C_ITEM.LSG_QTITEMPROD,4),
                           V_CDPRODUTO, P_CDFILIAL, ' ', ' ',
                           ' ', ' ', '4', TO_DATE(SYSDATE),
                           '2', ROUND(C_ITEM.LSG_VRUNITPROD,4), ROUND(C_ITEM.LSG_VRUNITPROD,4));
/*Grava dados do item na nota de sada*/
                       INSERT INTO ITEMPRODUTO
                          (CDFILIAL,     NRLANCTONF,   NRSEQITPROD,  CDPRODUTO,
                           CDPRODEMIS,   DSPRODEMIS,   IDATUVRESTOQ, QTITEMPROD,
                           VRUNITITEM,   VRDESCITEM,   VRTOTAITEM,   VRCONTITEM,
                           IDCONFORITEM, VRBRUTITEM,   VRDESPERITEM, CDFILIMOVI,
                           CDALMOXARIFE, CDLOCALESTOQ, NRLOTEESTQ,   NRSUBLOTE)
                       VALUES
                          (P_CDFILIAL, V_NRLANCTOS, V_SEQITEM, V_CDPRODUTO,
                           V_CDPRODUTO, V_NMPRODUTO, 'S', ROUND(C_ITEM.LSG_QTITEMPROD,4),
                           ROUND(C_ITEM.LSG_VRUNITPROD,4), 0, ROUND(C_ITEM.LSG_VRTOTAPROD,4), ROUND(C_ITEM.LSG_VRTOTAPROD,4),
                           'S', ROUND(C_ITEM.LSG_VRTOTAPROD,4), 0, P_CDFILIAL,
                           ' ', ' ', ' ', ' ');
                       V_SEQITEM := LPAD(TO_CHAR(TO_NUMBER(V_SEQITEM)+1),4,'0000');
                       V_TOTPROD :=  V_TOTPROD + ROUND(C_ITEM.LSG_VRTOTAPROD,4);
                     END IF;
                  END LOOP;
/*Se ocorreram erros nos produto, delete os lanamentos*/
                  IF V_ERRO = '1' THEN
                     DELETE FROM ITEMPRODUTO
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = V_NRLANCTOE;
                     DELETE FROM ITLANCTOEST
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCESTQ = V_NRLANCESTE;
                     DELETE FROM LANCTOESTOQ
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCESTQ = V_NRLANCESTE;
                     DELETE FROM NOTAFISCAL
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = V_NRLANCTOE;
                     DELETE FROM ITEMPRODUTO
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = V_NRLANCTOS;
                     DELETE FROM ITLANCTOEST
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCESTQ = V_NRLANCESTS;
                     DELETE FROM LANCTOESTOQ
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCESTQ = V_NRLANCESTS;
                     DELETE FROM DADOSADIC
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = V_NRLANCTOS;
                     DELETE FROM NOTAFISCAL
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = V_NRLANCTOS;
                  ELSE
/*Gera Impostos e Atualiza o Estoque para a nota de entrada*/
                     LSG_TRAB_IMPOSTO_ENTRADA(P_CDFILIAL, V_NRLANCTOE, V_NRLANCESTE, V_VRNOTAFISC);
                     ATUALIZA_ESTOQUE(P_CDFILIAL, TO_DATE(SYSDATE), TO_DATE(SYSDATE), P_CDFILIAL, V_NRLANCESTE);
/*Grava o valor da nota fiscal*/
                     UPDATE NOTAFISCAL
                        SET VRPRODUTOS = V_TOTPROD,
                            VRNOTAFISC = V_VRNOTAFISC
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = V_NRLANCTOE;
/*Gera Impostos e Atualiza o Estoque para a nota de sada*/
                     IMPOSTO_SAIDA(V_CDEMPRESA, V_INSCESTA, P_CDTIPOPERS, V_CDCLIENTE,
                                   P_CDFILIAL,  V_NRLANCTOS, TO_DATE(SYSDATE), V_VRNOTAFISC,
                                   V_NRLANCESTS);
                     ATUALIZA_ESTOQUE(P_CDFILIAL, TO_DATE(SYSDATE), TO_DATE(SYSDATE), P_CDFILIAL, V_NRLANCESTS);
/*Grava o valor da nota fiscal*/
                     UPDATE NOTAFISCAL
                        SET VRPRODUTOS = V_TOTPROD,
                            VRNOTAFISC = V_VRNOTAFISC
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = V_NRLANCTOS;
/*Altera o CST dos Itens da Nota Fiscal de Sada*/
                     FOR CST_PROD IN (SELECT CDSITUTRIBPR,
                                             CDFILIAL, NRLANCTONF, NRSEQITPROD
                                        FROM ITEMPRODUTO
                                       WHERE CDFILIAL = P_CDFILIAL
                                         AND NRLANCTONF = V_NRLANCTOS
                                         AND CDSITUTRIBPR IS NOT NULL) LOOP

                        UPDATE ITEMPRODUTO
                           SET CDSITUTRIBPR = '1'||SUBSTR(CDSITUTRIBPR,2,2)
                         WHERE CDFILIAL    = CST_PROD.CDFILIAL
                           AND NRLANCTONF  = CST_PROD.NRLANCTONF
                           AND NRSEQITPROD = CST_PROD.NRSEQITPROD;
                     END LOOP;
/*Altera o CST dos Impostos dos Itens da Nota Fiscal de Sada*/
                     FOR CST_ITIMP IN (SELECT CDSITUTRIBIT,
                                              CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS
                                        FROM ITEMPROIMPOS
                                       WHERE CDFILIAL = P_CDFILIAL
                                         AND NRLANCTONF = V_NRLANCTOS
                                         AND CDSITUTRIBIT IS NOT NULL) LOOP

                        UPDATE ITEMPROIMPOS
                           SET CDSITUTRIBIT = '1'||SUBSTR(CDSITUTRIBIT,2,2)
                         WHERE CDFILIAL     = CST_ITIMP.CDFILIAL
                           AND NRLANCTONF   = CST_ITIMP.NRLANCTONF
                           AND NRSEQITPROD  = CST_ITIMP.NRSEQITPROD
                           AND CDIMPOSTO    = CST_ITIMP.CDIMPOSTO
                           AND NRITPROIMPOS = CST_ITIMP.NRITPROIMPOS;
                     END LOOP;
/*Altera o CST dos Impostos da Nota Fiscal de Sada*/
                     FOR CST_IMP IN (SELECT  CDSITUTRIBNF,
                                              CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF
                                        FROM IMPOSTONF
                                       WHERE CDFILIAL = P_CDFILIAL
                                         AND NRLANCTONF = V_NRLANCTOS
                                         AND CDSITUTRIBNF IS NOT NULL) LOOP

                        UPDATE IMPOSTONF
                           SET CDSITUTRIBNF = '1'||SUBSTR(CDSITUTRIBNF,2,2)
                         WHERE CDFILIAL    = CST_IMP.CDFILIAL
                           AND NRLANCTONF  = CST_IMP.NRLANCTONF
                           AND CDIMPOSTO   = CST_IMP.CDIMPOSTO
                           AND NRIMPOSNF   = CST_IMP.NRIMPOSNF;
                     END LOOP;
                  END IF;
               END IF;/*Finaliza o If que verifica se o fornecedor existe*/
            END IF;/*Finala o If que verifica se existe a companhia existe*/
         END IF;/*Finala o If que impede a importao de uma nota vrias vezes*/
      END IF;/*Finala o If que verifica se a nota j foi importada*/
   END LOOP;/*Finaliza o Loop de Notas*/
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('LSG_GERA_NOTAFISCAL','5.42.000'); END;
/
