function crm30000_001_Tipo_Compromisso_Controller(General, templateManager)
{   
    
    /**
     * Função para definir se irá salver um
     * novo registro ou uma alteração de um 
     * registro existente.
     * 
     * @param {object(widget)} widget widget
     * ativa no modo edit.
     * 
    */
    this.saveCommitmentType = function(widget){
            
        var currentRow = widget.currentRow;
        
        if(currentRow.__is_new){
            
            this.saveNewCommitmentType(widget);
            
        }else{
            
            this.saveCommitmentTypeModification(widget);
            
        }
            
    };
    
    /**
     * Função para salvar um novo tipo de
     * compromisso.
     * 
     * @param {object(widget)} widget widget ativa
     * onde está sendo realizado o cadastro de um 
     * novo tipo de compromisso.
    */
    this.saveNewCommitmentType = function(widget){
        
        var currentRow = widget.currentRow;
        
        this.editIconPathOutput(currentRow);
        this.setColumnToReturnInCurrentRow(currentRow, "NRTIPOCOMPROMISSO");
        
        General.widgetSave(widget).then(function(response){
            
            var iconUrl = response.dataset.VALUES.DSCAMINHOICONE;
            
            currentRow.NRTIPOCOMPROMISSO = response.dataset.VALUES.NRTIPOCOMPROMISSO;
            currentRow.DSCAMINHOICONE = (iconUrl) ? iconUrl : "";
            
        });
                
    };
    
    /**
     * Função para setar a coluna a ser retornada
     * na resposta do 'save'.
     * 
     * @param {object} currentRow currentRow que receberá
     * a propriedade com o nome da coluna a ser retornada.
     * 
     * @param {string} columnName nome da coluna a ser
     * retornada.
    */
    this.setColumnToReturnInCurrentRow = function(currentRow, columnName){
    
        currentRow.__columns_to_return = [columnName];

    };
    
    /**
     * Função para salvar as alterações realizadas
     * em um registro.
     * 
     * @param {object(widget)} widget widget ativa,
     * no modo edit, onde foi feita as alterações
     * do registro.
    */
    this.saveCommitmentTypeModification = function(widget){
        
        var currentRow = widget.currentRow;
        
        this.editIconPathOutput(currentRow);
        
        General.widgetSave(widget).then(function(response){
            
            var iconUrl = response.dataset.VALUES.DSCAMINHOICONE;
            
            currentRow.DSCAMINHOICONE = (iconUrl) ? iconUrl : "";
            
            this.deleteImageUrlBackup(currentRow);
            widget.reload();
            
        }.bind(this));
        
    };
    
    /**
     * Função para deletar o backup do caminho
     * criado no inicio da rotina de edição.
     * 
     * @param {object} currentRow currentRow onde
     * foi salvo o backup da do caminho, que será
     * deletado.
    */
    this.deleteImageUrlBackup = function(currentRow){
        
        if(currentRow.IMAGEURLBACKUP){
            delete currentRow.IMAGEURLBACKUP;
        }
            
    };
    
    /**
     * Função para setar uma string vazia
     * quando o valor do caminhio do icone
     * estiver com um array vazio.
     * 
     * @param {object} currentRow currentRow da widget
     * ativa onde está sendo realizada a modificação
     * do campo 'ícone'.
    */
    this.editIconPathOutput = function(currentRow){
        
        if(currentRow.DSCAMINHOICONE === null || (typeof currentRow.DSCAMINHOICONE === "object" && currentRow.DSCAMINHOICONE.length === 0)){
            currentRow.DSCAMINHOICONE = "";
        }
            
    };
    
    /**
     * Função para setar a URL do icone do
     * tipo de compromisso em caso na currentRow da
     * widget de vizualização de icones, quando
     * for um tipo que for salvo e logo em seguida
     * for requisitado a vizualização do icone, a função
     * já irá atribuir o caminho retornado dentro do objeto
     * convertido na currentRow.
     * 
     * @param {object(widget)} widget widget ativa
     * onde será vizualizado o icone do tipo de compromisso
     * em caso.
    */
    this.setCommitmentTypeIconUrlInCurrentRow = function(widget){
        
        var commitmentTypeIconUrl = widget.parent.parent.currentRow.DSCAMINHOICONE;
        var currentRow = widget.currentRow;
        
        currentRow.DSCAMINHOICONE = (commitmentTypeIconUrl) ? commitmentTypeIconUrl : ""; 
        
    };
    
    /**
     * Função para editar as informações
     * de um tipo de compromisso.
     * 
     * @param {object(widget)} widget widget ativa
     * no modo view, onde se inicializará o processo
     * de edição.
    */
    this.editTypeCommitment = function(widget){
    
        var currentRow = widget.currentRow;
        
        this.createImageUrlBackup(currentRow);
        
        General.widgetEdit(widget);
    };
    
    /**
     * Função para criar um backup da url do icone
     * na currentRow.
     * 
     * @param {object} currentRow currentRow onde será
     * salvo o backup da url do icone.
     * 
    */
    this.createImageUrlBackup = function(currentRow){
        

        currentRow.IMAGEURLBACKUP = (currentRow.DSCAMINHOICONE) ? currentRow.DSCAMINHOICONE : "";
        
    };
    
    /**
     * Função para ativar a widget de visualização
     * do icone do tipo do compromisso em caso.
    */
    this.toVisualizeCommitmentTypeIcon = function(){
        
        var visualizationIconWidget = templateManager.container.getWidget("WDGT_COMMITMENT_TYPE_ICON");
        
        visualizationIconWidget.activate();
            
    };
    
    /**
     * Função para deletar o icone do tipo
     * do compromisso em caso.
     * 
     * @param {object(widget)} widget widget ativa
     * contendo o icone do tipo do compromisso em caso.
    */
    this.deleteCommitmentTypeIcon = function(widget){
        
        widget.currentRow = widget.parent.parent.currentRow;
        
        var currentRow = widget.currentRow;
        
        this.createImageUrlBackup(currentRow);
        
        currentRow.__is_new = false;
        currentRow.DSCAMINHOICONE = "";
        
        this.getParentWidgetDataDatasource(widget);
        
        widget.saveRow().catch(function(err) {
            ScreenService.showMessage(err.data.error);
        });
            
    };
    
    /**
     * Função para receber o objecto data, vindo do objecto
     * dataSource, do pai da widget recebida como parâmetro
     * e setar na própria widget recebida.
     * 
     * @param {object(widget)} widget widget ativa
     * contendo o icone do tipo do compromisso em caso.
    */
    this.getParentWidgetDataDatasource = function(widget){
        
        widget.dataSource.data = widget.parent.dataSource.data;
        
    };
   
}
Configuration(function(ContextRegister)
{
    ContextRegister.register('crm30000_001_Tipo_Compromisso_Controller', crm30000_001_Tipo_Compromisso_Controller);
});